searchData={"content_type":"text/markdown","items":[{"doc":"Elixir implementation of Algolia Search API.\n\nYou can interact with Algolia's API by creating a new client using `new/1`, and then using\nthe other functions in this modules to make requests with that client.","ref":"Algolia.html","title":"Algolia","type":"module"},{"doc":"Adds an object to an index, or replaces an existing one.\n\nIf the object does not have an `:objectID` or `\"objectID\"` key, then Algolia\nwill automatically generate one and add it to the object.\n\nThe `:id_attribute` option can be used to set the `:objectID` key based on an\nexisting key already on the object.","ref":"Algolia.html#add_object/4","title":"Algolia.add_object/4","type":"function"},{"doc":"# add an object with automatically generated object ID\n    Algolia.add_object(client, \"my_index\", %{\n      kind: \"fruit\",\n      color: \"red\",\n      name: \"apple\"\n    })\n\n    # add or replace an object based on the object ID\n    Algolia.add_object(client, \"my_index\", %{\n      objectID: \"123\",\n      kind: \"fruit\",\n      color: \"red\",\n      name: \"apple\"\n    })\n\n    # set the object ID based on another attribute\n    Algolia.add_object(client, \"my_index\", %{\n      kind: \"fruit\",\n      color: \"red\",\n      name: \"apple\"\n    }, id_attribute: :name)\n    # resulting objectID is \"apple\"","ref":"Algolia.html#add_object/4-examples","title":"Examples - Algolia.add_object/4","type":"function"},{"doc":"* `:id_attribute` - key to use as the `:objectID` of the object. If set, the\n  saved object will have both `:objectID` and this key set to the same value.\n* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#add_object/4-options","title":"Options - Algolia.add_object/4","type":"function"},{"doc":"Adds or replaces multiple objects in an index.\n\nIf any objects do not have an `:objectID` or `\"objectID\"` key, then Algolia\nwill automatically generate one and add it to the object.\n\nThe `:id_attribute` option can be used to set the `:objectID` key based on an\nexisting key already on the object.","ref":"Algolia.html#add_objects/4","title":"Algolia.add_objects/4","type":"function"},{"doc":"# with automatically assigned object IDs\n    Algolia.add_objects(client, \"my_index\", [\n      %{name: \"apple\"},\n      %{name: \"banana\"},\n      %{name: \"pear\"}\n    ])\n\n    # adding or replacing objects based on object ID\n    Algolia.add_objects(client, \"my_index\", [\n      %{objectID: \"fruit1\", name: \"apple\"},\n      %{objectID: \"fruit2\", name: \"banana\"},\n      %{objectID: \"fruit3\", name: \"pear\"}\n    ])\n\n    # use the `:name` as the object IDs\n    Algolia.add_objects(client, \"my_index\", [\n      %{name: \"apple\"},\n      %{name: \"banana\"},\n      %{name: \"pear\"}\n    ], id_attribute: :name)","ref":"Algolia.html#add_objects/4-examples","title":"Examples - Algolia.add_objects/4","type":"function"},{"doc":"* `:id_attribute` - key to use as the `:objectID` of the objects. If set, the\n  saved objects will have both `:objectID` and this key set to the same value.\n* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#add_objects/4-options","title":"Options - Algolia.add_objects/4","type":"function"},{"doc":"Browses a single index.\n\nBrowsing is similar to searching, but it skips ranking results and allows fetching more\nobjects.","ref":"Algolia.html#browse/3","title":"Algolia.browse/3","type":"function"},{"doc":"Algolia.browse(client, \"my_index\", filters: \"color:red AND kind:fruit\")","ref":"Algolia.html#browse/3-example","title":"Example - Algolia.browse/3","type":"function"},{"doc":"Any of Algolia's supported [search parameters](https://www.algolia.com/doc/api-reference/search-api-parameters/)\ncan be passed as options, with the exception of `:distinct` which is not supported when browsing.\n\n#","ref":"Algolia.html#browse/3-options","title":"Options - Algolia.browse/3","type":"function"},{"doc":"* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#browse/3-additional-options","title":"Additional options - Algolia.browse/3","type":"function"},{"doc":"Clears all objects from an index.","ref":"Algolia.html#clear_index/3","title":"Algolia.clear_index/3","type":"function"},{"doc":"* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#clear_index/3-options","title":"Options - Algolia.clear_index/3","type":"function"},{"doc":"Copies an index to a new one.","ref":"Algolia.html#copy_index/4","title":"Algolia.copy_index/4","type":"function"},{"doc":"* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#copy_index/4-options","title":"Options - Algolia.copy_index/4","type":"function"},{"doc":"Removes all objects matching a filter.","ref":"Algolia.html#delete_by/3","title":"Algolia.delete_by/3","type":"function"},{"doc":"iex> Algolia.delete_by(client, \"index\", filters: [\"score < 30\"])\n    {:ok,\n      %{\"indexName\" => \"index\",\n        \"taskId\" => 42,\n        \"deletedAt\" => \"2018-10-30T15:33:13.556Z\"}}","ref":"Algolia.html#delete_by/3-examples","title":"Examples - Algolia.delete_by/3","type":"function"},{"doc":"Allowed filter parameters:\n\n* `filters`\n* `facetFilters`\n* `numericFilters`\n* `aroundLatLng` and `aroundRadius` (these two need to be used together)\n* `insideBoundingBox`\n* `insidePolygon`\n\nThey have the same meaning as when used for a query (such as with `search/4` or `browse/3`).\nAt least one type of filter is required.\n\n#","ref":"Algolia.html#delete_by/3-options","title":"Options - Algolia.delete_by/3","type":"function"},{"doc":"* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#delete_by/3-additional-options","title":"Additional options - Algolia.delete_by/3","type":"function"},{"doc":"Deletes an index.","ref":"Algolia.html#delete_index/3","title":"Algolia.delete_index/3","type":"function"},{"doc":"* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#delete_index/3-options","title":"Options - Algolia.delete_index/3","type":"function"},{"doc":"Deletes a single object by its object ID.","ref":"Algolia.html#delete_object/4","title":"Algolia.delete_object/4","type":"function"},{"doc":"* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#delete_object/4-options","title":"Options - Algolia.delete_object/4","type":"function"},{"doc":"Deletes multiple objects by object ID.","ref":"Algolia.html#delete_objects/4","title":"Algolia.delete_objects/4","type":"function"},{"doc":"* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#delete_objects/4-options","title":"Options - Algolia.delete_objects/4","type":"function"},{"doc":"Gets the logs of the latest search and indexing operations.","ref":"Algolia.html#get_logs/2","title":"Algolia.get_logs/2","type":"function"},{"doc":"* `:indexName` - index for which log entries should be retrieved. When omitted,\n  log entries are retrieved across all indices.\n* `:length` - maximum number of entries to retrieve. Maximum allowed value: 1000.\n* `:offset` - first entry to retrieve (zero-based). Log entries are sorted by\n  decreasing date, therefore 0 designates the most recent log entry.\n* `:type` - type of log to retrieve: `:all`, `:query`, `:build` or `:error`. Defaults\n  to `:all`.\n* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#get_logs/2-options","title":"Options - Algolia.get_logs/2","type":"function"},{"doc":"Retrieves a single object from an index by ID.","ref":"Algolia.html#get_object/4","title":"Algolia.get_object/4","type":"function"},{"doc":"Algolia.get_object(client, \"my_index\", \"123\")","ref":"Algolia.html#get_object/4-example","title":"Example - Algolia.get_object/4","type":"function"},{"doc":"* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#get_object/4-options","title":"Options - Algolia.get_object/4","type":"function"},{"doc":"Gets the settings of a index.","ref":"Algolia.html#get_settings/3","title":"Algolia.get_settings/3","type":"function"},{"doc":"iex> Algolia.get_settings(client, \"my_index\")\n    {:ok,\n      %{\"minWordSizefor1Typo\" => 4,\n        \"minWordSizefor2Typos\" => 8,\n        \"hitsPerPage\" => 20,\n        \"attributesToIndex\" => nil,\n        \"attributesToRetrieve\" => nil,\n        \"attributesToSnippet\" => nil,\n        \"attributesToHighlight\" => nil,\n        \"ranking\" => [\n            \"typo\",\n            \"geo\",\n            \"words\",\n            \"proximity\",\n            \"attribute\",\n            \"exact\",\n            \"custom\"\n        ],\n        \"customRanking\" => nil,\n        \"separatorsToIndex\" => \"\",\n        \"queryType\" => \"prefixAll\"}}","ref":"Algolia.html#get_settings/3-example","title":"Example - Algolia.get_settings/3","type":"function"},{"doc":"* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#get_settings/3-options","title":"Options - Algolia.get_settings/3","type":"function"},{"doc":"Lists all indexes.","ref":"Algolia.html#list_indexes/2","title":"Algolia.list_indexes/2","type":"function"},{"doc":"* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#list_indexes/2-options","title":"Options - Algolia.list_indexes/2","type":"function"},{"doc":"Moves an index to new one.","ref":"Algolia.html#move_index/4","title":"Algolia.move_index/4","type":"function"},{"doc":"* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#move_index/4-options","title":"Options - Algolia.move_index/4","type":"function"},{"doc":"Performs multiple search queries in a single request.\n\nEach entry in `queries` should be a map with `:index_name` indicating which index to search,\nand the remaining keys corresponding to [Algolia search parameters](https://www.algolia.com/doc/api-reference/search-api-parameters/).","ref":"Algolia.html#multi/3","title":"Algolia.multi/3","type":"function"},{"doc":"Algolia.multi(client, [\n      %{index_name: \"my_index1\", query: \"search query\"},\n      %{index_name: \"my_index2\", query: \"another query\", hitsPerPage: 3},\n      %{index_name: \"my_index3\", query: \"3rd query\", tagFilters: \"promotion\"}\n    ])","ref":"Algolia.html#multi/3-examples","title":"Examples - Algolia.multi/3","type":"function"},{"doc":"* `:strategy` - strategy to use to decide whether to continue with additional queries. Can be\n  either `:none` or `:stop_if_enough_matches`. Defaults to `:none`. See\n  [Algolia's documentation](https://www.algolia.com/doc/rest-api/search/#search-multiple-indices)\n  for more information about the difference between these two strategies.\n* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#multi/3-options","title":"Options - Algolia.multi/3","type":"function"},{"doc":"Creates a new Algolia client.\n\nA client must be passed to any function that makes a request to Algolia.","ref":"Algolia.html#new/1","title":"Algolia.new/1","type":"function"},{"doc":"client = Algolia.new(\n      api_key: \"my_api_key\",\n      application_id: \"my_application_id\"\n    )\n    Algolia.search(client, \"my_index\", \"some query\")\n\n    # adding logging middleware\n    client = Algolia.new(\n      middleware: fn middleware ->\n        middleware ++ [\n          {Tesla.Middleware.Logger, filter_headers: [\"X-Algolia-API-Key\"]}\n        ]\n      end\n    )\n\n    # set a custom adapter\n    client = Algolia.new(adapter: Tesla.Adapter.Mint)","ref":"Algolia.html#new/1-examples","title":"Examples - Algolia.new/1","type":"function"},{"doc":"* `:api_key` - the API key to use for Algolia. If unset, reads from the `ALGOLIA_API_KEY`\n  environment variable or the `:api_key` key in the `:algolia` application config.\n* `:application_id` - the application ID to use for Algolia. If unset, reads from the\n  `ALGOLIA_APPLICATION_ID` environment variable or the `:application_id` key in the\n  `:algolia` application config.\n* `:middleware` - a function that can be used to alter the default list of Tesla middleware\n  that will be used. The function takes the default list of middleware as an argument, so\n  you can inject middleware as needed. Note that removing any of the default middleware\n  might break the client.\n* `:adapter` - the Tesla HTTP adapter to use. Defaults to Tesla's default adapter, which\n  is `:httpc` by default but can be overridden in the `:tesla` application config.","ref":"Algolia.html#new/1-options","title":"Options - Algolia.new/1","type":"function"},{"doc":"Partially updates a single object.","ref":"Algolia.html#partial_update_object/5","title":"Algolia.partial_update_object/5","type":"function"},{"doc":"Algolia.partial_update_object(client, \"my_index\", %{\n      objectID: \"1\",\n      name: \"apple\"\n    })\n\n    # don't create the object if it doesn't already exist\n    Algolia.partial_update_object(client, \"my_index\", %{\n      id: \"1\",\n      name: \"apple\"\n    }, upsert?: false)","ref":"Algolia.html#partial_update_object/5-examples","title":"Examples - Algolia.partial_update_object/5","type":"function"},{"doc":"* `:upsert?` - whether to create the record if it doesn't already exist. Defaults to `true`.\n* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#partial_update_object/5-options","title":"Options - Algolia.partial_update_object/5","type":"function"},{"doc":"Partially updates multiple objects.","ref":"Algolia.html#partial_update_objects/4","title":"Algolia.partial_update_objects/4","type":"function"},{"doc":"Algolia.partial_update_objects(client, \"my_index\", [\n      %{objectID: \"1\", name: \"apple\"},\n      %{objectID: \"2\", name: \"orange\"}\n    ])\n\n    # don't create objects if they don't already exist,\n    # and use `:id` for the object ID\n    Algolia.partial_update_objects(client, \"my_index\", [\n      %{id: \"1\", name: \"apple\"},\n      %{id: \"2\", name: \"orange\"}\n    ], upsert?: false, id_attribute: :id)","ref":"Algolia.html#partial_update_objects/4-examples","title":"Examples - Algolia.partial_update_objects/4","type":"function"},{"doc":"* `:upsert?` - whether to create any records that don't already exist. Defaults to `true`.\n* `:id_attribute` - key to use as the `:objectID` of the objects.\n* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#partial_update_objects/4-options","title":"Options - Algolia.partial_update_objects/4","type":"function"},{"doc":"Pushes events to the Insights API.\n\nSee Algolia's documentation for the [send events endpoint](https://www.algolia.com/doc/rest-api/insights/#send-events)\nfor more information on the fields that events should include.","ref":"Algolia.html#push_events/3","title":"Algolia.push_events/3","type":"function"},{"doc":"Algolia.push_events(client, [\n      %{\n        \"eventType\" => \"click\",\n        \"eventName\" => \"Product Clicked\",\n        \"index\" => \"products\",\n        \"userToken\" => \"user-123456\",\n        \"objectIDs\" => [\"9780545139700\", \"9780439784542\"],\n        \"queryID\" => \"43b15df305339e827f0ac0bdc5ebcaa7\",\n        \"positions\" => [7, 6]\n      }\n    ])","ref":"Algolia.html#push_events/3-examples","title":"Examples - Algolia.push_events/3","type":"function"},{"doc":"* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#push_events/3-options","title":"Options - Algolia.push_events/3","type":"function"},{"doc":"Saves a single object, replacing it if it already exists.\n\nUnlike `add_object/4`, the object must already have an object ID. The `:id_attribute`\noption can still be used to set an object ID based on another attribute.","ref":"Algolia.html#save_object/4","title":"Algolia.save_object/4","type":"function"},{"doc":"# add or replace an object based on the object ID\n    Algolia.save_object(client, \"my_index\", %{\n      objectID: \"123\",\n      kind: \"fruit\",\n      color: \"red\",\n      name: \"apple\"\n    })\n\n    # pass the object ID as its own argument\n    Algolia.save_object(client, \"my_index\", %{\n      kind: \"fruit\",\n      color: \"red\",\n      name: \"apple\"\n    }, \"123\")\n\n    # set the object ID based on another attribute\n    Algolia.save_object(client, \"my_index\", %{\n      kind: \"fruit\",\n      color: \"red\",\n      name: \"apple\"\n    }, id_attribute: :name)\n    # resulting objectID is \"apple\"","ref":"Algolia.html#save_object/4-examples","title":"Examples - Algolia.save_object/4","type":"function"},{"doc":"* `:id_attribute` - key to use as the `:objectID` of the object. If set, the\n  saved object will have both `:objectID` and this key set to the same value.\n* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#save_object/4-options","title":"Options - Algolia.save_object/4","type":"function"},{"doc":"Saves multiple objects, replacing any that already exist.\n\nUnlike `add_objects/4`, the objects must already have object IDs. The `:id_attribute`\noption can still be used to set the object IDs based on another attribute.","ref":"Algolia.html#save_objects/4","title":"Algolia.save_objects/4","type":"function"},{"doc":"Algolia.save_objects(client, \"my_index\", [\n      %{objectID: \"1\", name: \"apple\"},\n      %{objectID: \"2\", name: \"orange\"}\n    ])\n\n    # use `:id` for the object ID\n    Algolia.save_objects(client, \"my_index\", [\n      %{id: \"1\", name: \"apple\"},\n      %{id: \"2\", name: \"orange\"}\n    ], id_attribute: :id)","ref":"Algolia.html#save_objects/4-examples","title":"Examples - Algolia.save_objects/4","type":"function"},{"doc":"* `:id_attribute` - key to use as the `:objectID` of the objects.\n* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#save_objects/4-options","title":"Options - Algolia.save_objects/4","type":"function"},{"doc":"Searches a single index.","ref":"Algolia.html#search/4","title":"Algolia.search/4","type":"function"},{"doc":"# basic search\n    Algolia.search(client, \"my_index\", \"some query\")\n\n    # with search parameters\n    Algolia.search(client, \"my_index\", \"some query\",\n      attributesToRetrieve: \"firstname\",\n      hitsPerPage: 20\n    )","ref":"Algolia.html#search/4-examples","title":"Examples - Algolia.search/4","type":"function"},{"doc":"Any of Algolia's supported [search parameters](https://www.algolia.com/doc/api-reference/search-api-parameters/)\ncan be passed as options.\n\n#","ref":"Algolia.html#search/4-options","title":"Options - Algolia.search/4","type":"function"},{"doc":"* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#search/4-additional-options","title":"Additional options - Algolia.search/4","type":"function"},{"doc":"Searches for facet values.\n\nEnables you to search through the values of a facet attribute, selecting\nonly a subset of those values that meet a given criteria.\n\nFor a facet attribute to be searchable, it must have been declared in the\n`attributesForFaceting` index setting with the `searchable` modifier.\n\nFacet-searching only affects facet values. It does not impact the underlying\nindex search.","ref":"Algolia.html#search_for_facet_values/5","title":"Algolia.search_for_facet_values/5","type":"function"},{"doc":"iex> Algolia.search_for_facet_values(\"species\", \"phylum\", \"dophyta\")\n    {:ok,\n      %{\"exhaustiveFacetsCount\" => false,\n        \"facetHits\" => [\n          %{\n            \"count\" => 9000,\n            \"highlighted\" => \"Pteri dophyta \",\n            \"value\" => \"Pteridophyta\"\n          },\n          %{\n            \"count\" => 7000,\n            \"highlighted\" => \"Rho dophyta \",\n            \"value\" => \"Rhodophyta\"\n          },\n          %{\n            \"count\" => 150,\n            \"highlighted\" => \"Cyca dophyta \",\n            \"value\" => \"Cycadophyta\"\n          }\n        ],\n        \"processingTimeMS\" => 42}}","ref":"Algolia.html#search_for_facet_values/5-examples","title":"Examples - Algolia.search_for_facet_values/5","type":"function"},{"doc":"Many of Algolia's supported [search parameters](https://www.algolia.com/doc/api-reference/search-api-parameters/)\ncan be passed as options to filter the objects that are matched.\n\n#","ref":"Algolia.html#search_for_facet_values/5-options","title":"Options - Algolia.search_for_facet_values/5","type":"function"},{"doc":"* `:sortFacetValuesBy` - control how facets are sorted. Either `\"count\"` (by count, descending)\n  or `\"alpha\"` (by value alphabetically, ascending). Defaults to `\"count\"`.\n* `:maxFacetHits` - maximum number of hits to return. Defaults to 10. Cannot exceed 100.\n* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#search_for_facet_values/5-additional-options","title":"Additional options - Algolia.search_for_facet_values/5","type":"function"},{"doc":"Sets the settings of a index.","ref":"Algolia.html#set_settings/4","title":"Algolia.set_settings/4","type":"function"},{"doc":"iex> Algolia.set_settings(client, \"my_index\", %{hitsPerPage: 20})\n    {:ok,\n      %{\"updatedAt\" => \"2013-08-21T13:20:18.960Z\",\n        \"taskID\" => 10210332.\n        \"indexName\" => \"my_index\"}}","ref":"Algolia.html#set_settings/4-example","title":"Example - Algolia.set_settings/4","type":"function"},{"doc":"* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#set_settings/4-options","title":"Options - Algolia.set_settings/4","type":"function"},{"doc":"Waits on the task created by a previous request.\n\nThis is a convenient variation of `wait_task/4` that accepts a response from another\nAPI function. You can pipe another API function into `wait/3` to only return the\nresponse once the task is completed.","ref":"Algolia.html#wait/3","title":"Algolia.wait/3","type":"function"},{"doc":"client\n    |> Algolia.save_object(\"my_index\", %{id: \"123\"}, id_attribute: :id)\n    |> Algolia.wait(client)\n\n    client\n    |> Algolia.save_objects(\"my_index\", [\n      %{id: \"123\"},\n      %{id: \"234\"}\n    ], id_attribute: :id)\n    |> Algolia.wait(client, retry_delay: 2_000)","ref":"Algolia.html#wait/3-examples","title":"Examples - Algolia.wait/3","type":"function"},{"doc":"* `:retry_delay` - number of milliseconds to wait before each request to Algolia to\n  check for task completion. Defaults to `1_000`, or one second.\n* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#wait/3-options","title":"Options - Algolia.wait/3","type":"function"},{"doc":"Waits for a task for an index to complete.\n\nReturns `:ok` when the task is completed.","ref":"Algolia.html#wait_task/4","title":"Algolia.wait_task/4","type":"function"},{"doc":"{:ok, %{\"taskID\" => task_id, \"indexName\" => index}} =\n      Algolia.save_object(client, %{id: \"123\"}, id_attribute: :id)\n\n    Algolia.wait_task(client, index, task_id)\n\nSee `wait/3` for a convenient shortcut using piping.","ref":"Algolia.html#wait_task/4-example","title":"Example - Algolia.wait_task/4","type":"function"},{"doc":"* `:retry_delay` - number of milliseconds to wait before each request to Algolia to\n  check for task completion. Defaults to `1_000`, or one second.\n* `:headers` - list of additional HTTP headers to include in the request.","ref":"Algolia.html#wait_task/4-options","title":"Options - Algolia.wait_task/4","type":"function"},{"doc":"A client to use to communicate with Algolia.\n\nAll API functions require a client to be able to make requests.","ref":"Algolia.html#t:client/0","title":"Algolia.client/0","type":"type"},{"doc":"The name of an Algolia index.","ref":"Algolia.html#t:index/0","title":"Algolia.index/0","type":"type"},{"doc":"","ref":"Algolia.html#t:multi_strategy/0","title":"Algolia.multi_strategy/0","type":"type"},{"doc":"Generic options that can be passed to any API function.","ref":"Algolia.html#t:request_option/0","title":"Algolia.request_option/0","type":"type"},{"doc":"","ref":"Algolia.html#t:result/1","title":"Algolia.result/1","type":"type"},{"doc":"","ref":"Algolia.Middleware.BaseUrl.html","title":"Algolia.Middleware.BaseUrl","type":"module"},{"doc":"","ref":"Algolia.Middleware.Response.html","title":"Algolia.Middleware.Response","type":"module"},{"doc":"","ref":"Algolia.Middleware.Retry.html","title":"Algolia.Middleware.Retry","type":"module"},{"doc":"","ref":"Algolia.InvalidObjectIDError.html","title":"Algolia.InvalidObjectIDError","type":"exception"},{"doc":"","ref":"Algolia.MissingAPIKeyError.html","title":"Algolia.MissingAPIKeyError","type":"exception"},{"doc":"","ref":"Algolia.MissingApplicationIDError.html","title":"Algolia.MissingApplicationIDError","type":"exception"},{"doc":"","ref":"readme.html","title":"README","type":"extras"},{"doc":"This is an Elixir implementation of the Algolia search API.\n\nTo use it, add the following to your dependencies:\n\n```elixir\ndefp deps do\n  [{:algolia, \"~> 0.9.0\", hex: :algolia_ex}]\nend\n```","ref":"readme.html#algolia","title":"Algolia - README","type":"extras"},{"doc":"##","ref":"readme.html#configuration","title":"Configuration - README","type":"extras"},{"doc":"ALGOLIA_APPLICATION_ID=YOUR_APPLICATION_ID\n    ALGOLIA_API_KEY=YOUR_API_KEY\n\n##","ref":"readme.html#using-environment-variables","title":"Using environment variables: - README","type":"extras"},{"doc":"```elixir\nconfig :algolia,\n  application_id: \"YOUR_APPLICATION_ID\",\n  api_key: \"YOUR_API_KEY\"\n```\n\n**Note**: You must use _admin_ API key rather than a _search_ API key to enable write access.\n\n#","ref":"readme.html#using-config","title":"Using config: - README","type":"extras"},{"doc":"All responses are deserialized into maps before returning one of these responses:\n\n  - `{:ok, response}`\n  - `{:error, error_code, response}`\n  - `{:error, \"Cannot connect to Algolia\"}`: The client implements retry\n      strategy on all Algolia hosts with increasing timeout. It should only\n      return this error when it has tried all 4 hosts.\n      [**More details here**](https://www.algolia.com/doc/rest#quick-reference).","ref":"readme.html#return-values","title":"Return values - README","type":"extras"},{"doc":"#","ref":"readme.html#examples","title":"Examples - README","type":"extras"},{"doc":"All API function that make requests require a client.\n\n```elixir\nclient = Algolia.new()\n```\n\n#","ref":"readme.html#creating-a-client","title":"Creating a client - README","type":"extras"},{"doc":"##","ref":"readme.html#searching","title":"Searching - README","type":"extras"},{"doc":"```elixir\nAlgolia.search(client, \"my_index\", \"some query\")\n```\n\nWith options:\n\n```elixir\nAlgolia.search(client, \"my_index\", \"some query\", attributesToRetrieve: \"firstname\", hitsPerPage: 20)\n```\n\nSee all available search options [**here**](https://www.algolia.com/doc/rest#full-text-search-parameters).\n\n##","ref":"readme.html#searching-an-index","title":"Searching an index - README","type":"extras"},{"doc":"Browsing is like search but skips most ranking and allows fetching more results at once.\n\n```elixir\nAlgolia.browse(client, \"my_index\", query: \"some query\", filter: \"color:red\")\n```\n\n##","ref":"readme.html#browsing-an-index","title":"Browsing an index - README","type":"extras"},{"doc":"```elixir\nAlgolia.multi(client, [\n  %{index_name: \"my_index1\", query: \"search query\"},\n  %{index_name: \"my_index2\", query: \"another query\", hitsPerPage: 3},\n  %{index_name: \"my_index3\", query: \"3rd query\", tagFilters: \"promotion\"}\n])\n```\n\nYou can specify a strategy to optimize your multiple queries:\n\n- `:none`: Execute the sequence of queries until the end.\n- `stop_if_enough_matches`: Execute the sequence of queries until the number of hits is reached by the sum of hits.\n\n```elixir\nAlgolia.multi(client, [query1, query2], strategy: :stop_if_enough_matches)\n```\n\n#","ref":"readme.html#multiple-queries-at-once","title":"Multiple queries at once - README","type":"extras"},{"doc":"All `save_*` operations will overwrite the object at the objectID.\n\nSave a single object to index without specifying objectID. You must have `objectID`\ninside object, or use the `id_attribute` option (see below).\n\n```elixir\nAlgolia.save_object(client, \"my_index\", %{objectID: \"1\"})\n```\n\nSave a single object with a given objectID:\n\n```elixir\nAlgolia.save_object(client, \"my_index\", %{title: \"hello\"}, \"12345\")\n```\n\nSave multiple objects to an index:\n\n```elixir\nAlgolia.save_objects(client, \"my_index\", [%{objectID: \"1\"}, %{objectID: \"2\"}])\n```\n\n#","ref":"readme.html#saving","title":"Saving - README","type":"extras"},{"doc":"Partially update a single object:\n\n```elixir\nAlgolia.partial_update_object(client, \"my_index\", %{title: \"hello\"}, \"12345\")\n```\n\nUpdate multiple objects. You must have `objectID` in each object, or use the `id_attribute` option (see below).\n\n```elixir\nAlgolia.partial_update_objects(client, \"my_index\", [%{objectID: \"1\"}, %{objectID: \"2\"}])\n```\n\nPartial update by default creates a new object if an object does not exist at the\nobjectID. You can turn this off by passing `false` to the `:upsert?` option.\n\n```elixir\nAlgolia.partial_update_object(client, \"my_index\", %{title: \"hello\"}, \"12345\", upsert?: false)\nAlgolia.partial_update_objects(client, \"my_index\", [%{id: \"1\"}, %{id: \"2\"}], id_attribute: :id, upsert?: false)\n```\n\n### `id_attribute` option\n\nAll write functions such as `save_object` and `partial_update_object` come with an `id_attribute` option that lets\nyou specify the `objectID` from an existing field in the object, so you do not have to generate it yourself.\n\n```elixir\nAlgolia.save_object(client, \"my_index\", %{id: \"2\"}, id_attribute: :id)\n```\n\nIt also works for batch operations, such as `save_objects` and `partial_update_objects`:\n\n```elixir\nAlgolia.save_objects(client, \"my_index\", [%{id: \"1\"}, %{id: \"2\"}], id_attribute: :id)\n```\n\n#","ref":"readme.html#updating","title":"Updating - README","type":"extras"},{"doc":"All write operations can be waited on by simply piping the response into `wait/1`:\n\n```elixir\nclient\n|> Algolia.save_object(\"my_index\", %{id: \"123\"})\n|> Algolia.wait(client)\n```\n\nThe client polls the server to check the status of the task.\nYou can specify a time (in milliseconds) between each tick of the poll; the default is 1000ms (1 second).\n\n```elixir\nclient\n|> Algolia.save_object(\"my_index\", %{id: \"123\"})\n|> Algolia.wait(client, retry_delay: 2_000)\n```\n\nYou can also explicitly pass a `taskID` to `wait_task`:\n\n\n```elixir\n{:ok, %{\"taskID\" => task_id, \"indexName\" => index}}\n  = Algolia.save_object(client, \"my_index\", %{id: \"123\"})\n\nAlgolia.wait_task(client, index, task_id)\n```\n\nOptionally including the poll interval:\n\n```elixir\nAlgolia.wait(client, index, task_id, retry_delay: 2_000)\n```\n\n#","ref":"readme.html#wait-for-task","title":"Wait for task - README","type":"extras"},{"doc":"##","ref":"readme.html#index-related-operations","title":"Index related operations - README","type":"extras"},{"doc":"```elixir\nAlgolia.list_indexes(client)\n```\n\n##","ref":"readme.html#listing-all-indexes","title":"Listing all indexes - README","type":"extras"},{"doc":"```elixir\nAlgolia.move_index(client, source_index, destination_index)\n```\n\n##","ref":"readme.html#move-an-index","title":"Move an index - README","type":"extras"},{"doc":"```elixir\nAlgolia.copy_index(client, source_index, destination_index)\n```\n\n##","ref":"readme.html#copy-an-index","title":"Copy an index - README","type":"extras"},{"doc":"```elixir\nAlgolia.clear_index(client, index)\n```\n\n#","ref":"readme.html#clear-an-index","title":"Clear an index - README","type":"extras"},{"doc":"##","ref":"readme.html#settings","title":"Settings - README","type":"extras"},{"doc":"```elixir\nAlgolia.get_settings(client, index)\n```\n\nExample response:\n\n```elixir\n{:ok,\n  %{\"minWordSizefor1Typo\" => 4,\n    \"minWordSizefor2Typos\" => 8,\n    \"hitsPerPage\" => 20,\n    \"attributesToIndex\" => nil,\n    \"attributesToRetrieve\" => nil,\n    \"attributesToSnippet\" => nil,\n    \"attributesToHighlight\" => nil,\n    \"ranking\" => [\n        \"typo\",\n        \"geo\",\n        \"words\",\n        \"proximity\",\n        \"attribute\",\n        \"exact\",\n        \"custom\"\n    ],\n    \"customRanking\" => nil,\n    \"separatorsToIndex\" => \"\",\n    \"queryType\" => \"prefixAll\"}}\n```\n\n##","ref":"readme.html#get-index-settings","title":"Get index settings - README","type":"extras"},{"doc":"```elixir\nAlgolia.set_settings(client, index, %{\"hitsPerPage\" => 20})\n\n> {:ok, %{\"updatedAt\" => \"2013-08-21T13:20:18.960Z\",\n          \"taskID\" => 10210332.\n          \"indexName\" => \"my_index\"}}\n```\n\n#","ref":"readme.html#update-index-settings","title":"Update index settings - README","type":"extras"},{"doc":"##","ref":"readme.html#insights","title":"Insights - README","type":"extras"},{"doc":"```elixir\nAlgolia.push_events(client, [\n  %{\n    \"eventType\" => \"click\",\n    \"eventName\" => \"Product Clicked\",\n    \"index\" => \"products\",\n    \"userToken\" => \"user-123456\",\n    \"objectIDs\" => [\"9780545139700\", \"9780439784542\"],\n    \"queryID\" => \"43b15df305339e827f0ac0bdc5ebcaa7\",\n    \"positions\" => [7, 6]\n  }\n])\n```","ref":"readme.html#push-events","title":"Push events - README","type":"extras"}]}